@@ -16,6 +16,7 @@ import datetime
 from typing import List, Mapping
 import grpc
 import itertools
+
 from nvidia_clara.grpc import common_pb2, jobs_pb2, jobs_pb2_grpc
 from nvidia_clara.base_client import BaseClient
 import nvidia_clara.job_types as job_types
@@ -222,15 +223,15 @@ class JobsClient(BaseClient, JobsClientStub):
 
         try:
             # Check to see if in form of seconds since year one
-            seconds_int = float(seconds_since_year_one.value) - 62167219200
+            seconds_int = float(seconds_since_year_one.value) - 62135596800
         except:
             # Otherwise parse timestamp
-            return datetime.datetime.strptime(seconds_since_year_one, "%Y-%m-%d %H:%M:%SZ")
+            return datetime.datetime.strptime(seconds_since_year_one, "%Y-%m-%d %H:%M:%SZ").astimezone(datetime.timezone.utc)
 
         if seconds_int < 0:
             return None
 
-        result_date = datetime.datetime.fromtimestamp(seconds_int)
+        result_date = datetime.datetime.fromtimestamp(seconds_int).astimezone(datetime.timezone.utc)
 
         return result_date
 
@@ -419,11 +420,21 @@ class JobsClient(BaseClient, JobsClientStub):
             request_filter = jobs_pb2.JobsListRequest.JobFilter
 
             if job_filter.completed_before is not None:
-                seconds = (job_filter.completed_before - datetime.datetime(1, 1, 1)).total_seconds()
+                day_one = datetime.datetime(1, 1, 1)
+                if job_filter.completed_before.tzinfo is not None \
+                        and job_filter.completed_before.tzinfo.utcoffset(job_filter.completed_before) is not None:
+                    day_one = datetime.datetime(1, 1, 1, tzinfo=job_filter.completed_before.tzinfo)
+
+                seconds = (job_filter.completed_before - day_one).total_seconds()
                 request.filter.completed_before.value = int(seconds)
 
             if job_filter.created_after is not None:
-                seconds = (job_filter.created_after - datetime.datetime(1, 1, 1)).total_seconds()
+                day_one = datetime.datetime(1, 1, 1)
+                if job_filter.created_after.tzinfo is not None \
+                        and job_filter.created_after.tzinfo.utcoffset(job_filter.created_after) is not None:
+                    day_one = datetime.datetime(1, 1, 1, tzinfo=job_filter.created_after.tzinfo)
+
+                seconds = (job_filter.created_after - day_one).total_seconds()
                 request.filter.created_after.value = int(seconds)
 
             if job_filter.has_job_state is not None:
